@@ -1,3 +1,4 @@
+from pathlib import Path
 from typing import Set
 
 
@@ -63,7 +64,15 @@ class UnexpectedArgument(ConfigurationError):
         super().__init__(f"Override {trace}'s arguments {overrides}.")
 
 
-class MissingPath(ConfigurationError):
+class ParamsFileNotExists(ConfigurationError):
+    def __init__(
+        self,
+        path: Path,
+    ) -> None:
+        super().__init__(f"Params file '{path}' doesn't exist.")
+
+
+class MissingDumpPath(ConfigurationError):
     def __init__(self) -> None:
         super().__init__("Cannot dump params if path is not specified.")
 
