@@ -28,9 +28,10 @@ import smartparams.utils.typing as typeutil
 from smartparams.exceptions import (
     ConfigurationError,
     DummyError,
-    MissingPath,
+    MissingDumpPath,
     ObjectInvalidOptionError,
     ObjectNotRegistered,
+    ParamsFileNotExists,
     UnexpectedTypeOptionArguments,
 )
 from smartparams.lab import SmartLab
@@ -658,14 +659,17 @@ class Smart(Generic[T]):
         Smart.strict = Smart.strict or args.strict
         Smart.debug = Smart.debug or args.debug
 
-        if args.path and args.path.exists():
-            self.update_from(args.path)
+        if args.path:
+            if args.path.exists():
+                self.update_from(args.path)
+            if args.mode:
+                self.update_from(args.path.with_suffix(f'.{args.mode}{args.path.suffix}'))
 
         self.update_from(args.params)
 
         if args.dump:
             if not args.path:
-                raise MissingPath()
+                raise MissingDumpPath()
 
             save_data(
                 data=self.representation(
@@ -679,10 +683,14 @@ class Smart(Generic[T]):
                 data=self._get_print_data(args),
                 fmt=args.format,
             )
-        elif function is None:
-            self()
         else:
-            function(self)
+            if not args.mode and args.path and not args.path.exists():
+                raise ParamsFileNotExists(args.path)
+
+            if function is None:
+                self()
+            else:
+                function(self)
 
     def _get_print_data(
         self,
