@@ -41,13 +41,13 @@ def parse_object(
 
 def import_callable(
     name: str,
-    location: str,
+    trace: str,
 ) -> Callable:
     obj = locate(name)
     if obj is None:
-        raise ObjectNotFoundError(name, location)
+        raise ObjectNotFoundError(name, trace)
     if not callable(obj):
-        raise ObjectNotCallableError(name, location)
+        raise ObjectNotCallableError(name, trace)
     return obj
 
 
@@ -89,11 +89,11 @@ def get_type_hints(signature: inspect.Signature) -> Dict[str, Any]:
 def check_overrides(
     params: Dict[str, Any],
     kwargs: Dict[str, Any],
-    callable_name: str,
+    trace: str,
     raise_error: bool,
 ) -> None:
     if overrides := set(params).intersection(kwargs):
-        exc = UnexpectedArgument(callable_name, overrides)
+        exc = UnexpectedArgument(trace, overrides)
         if raise_error:
             raise exc
         warnings.warn(exc.message)
@@ -102,12 +102,12 @@ def check_overrides(
 def check_missings(
     kwargs: Dict[str, Any],
     missing_value: str,
-    callable_name: str,
+    trace: str,
     raise_error: bool,
 ) -> None:
     for name, value in kwargs.items():
         if isinstance(value, str) and value.endswith(missing_value):
-            exc = MissingArgumentValue(callable_name, name)
+            exc = MissingArgumentValue(trace, name)
             if raise_error:
                 raise exc
             warnings.warn(exc.message)
@@ -117,7 +117,7 @@ def check_typings(
     callable_: Callable,
     args: Tuple[Any, ...],
     kwargs: Dict[str, Any],
-    callable_name: str,
+    trace: str,
     raise_error: bool,
 ) -> None:
     if callable_ is dict:
@@ -127,13 +127,13 @@ def check_typings(
     try:
         arguments = signature.bind(*args, **kwargs).arguments
     except TypeError as e:
-        raise MissingArgument(callable_name, " ".join(e.args))
+        raise MissingArgument(trace, " ".join(e.args))
 
     for name, expected_type in get_type_hints(signature).items():
         if name in arguments:
             try:
                 check_type(
-                    argname=f"{callable_name}'s argument '{name}'",
+                    argname=f"{trace}'s argument '{name}'",
                     value=arguments[name],
                     expected_type=expected_type,
                 )
@@ -144,22 +144,20 @@ def check_typings(
                 warnings.warn(exc.message)
 
 
-def convert_to_primitive_types(
+def convert_to_primitives(
     obj: Any,
-    missing_value: str,
+    unknown_type: str,
 ) -> Any:
-    if obj is None or isinstance(obj, (bool, int, float, str)):
+    if isinstance(obj, (bool, int, float, str, type(None))):
         return obj
 
     if isinstance(obj, Mapping):
         return {
-            convert_to_primitive_types(k, missing_value): convert_to_primitive_types(
-                v, missing_value
-            )
+            convert_to_primitives(k, unknown_type): convert_to_primitives(v, unknown_type)
             for k, v in obj.items()
         }
 
     if isinstance(obj, Sequence):
-        return [convert_to_primitive_types(item, missing_value) for item in obj]
+        return [convert_to_primitives(item, unknown_type) for item in obj]
 
-    return missing_value
+    return unknown_type
