@@ -8,7 +8,8 @@ from smartparams.exceptions import (
     ArgumentTypeError,
     MissingArgument,
     MissingArgumentValue,
-    MissingPath,
+    MissingDumpPath,
+    ParamsFileNotExists,
     UnexpectedArgument,
 )
 from tests.custom_classes import (
@@ -67,7 +68,7 @@ class TestSmartRunCase(IntegrationCase):
 
     @patch('smartparams.utils.cli.sys', Mock(argv='script.py --dump'.split()))
     def test_run__dump_no_path(self) -> None:
-        self.assertRaises(MissingPath, self.smart.run, function=Mock(), path=None)
+        self.assertRaises(MissingDumpPath, self.smart.run, function=Mock(), path=None)
 
     @patch('smartparams.utils.cli.sys', Mock(argv='script.py --print params'.split()))
     @patch('smartparams.utils.io.print')
@@ -94,6 +95,9 @@ class TestSmartRunCase(IntegrationCase):
     def test_run__strict(self) -> None:
         self.assertRaises(ArgumentTypeError, self.smart.run, function=lambda x: x())
 
+    def test_run__function__no_file(self) -> None:
+        self.assertRaises(ParamsFileNotExists, self.smart.run, path=Path('/does_not_exist.yaml'))
+
     @patch('smartparams.smart.load_data', Mock(return_value={'arg1': 'string'}))
     def test_run__function(self) -> None:
         function = Mock()
