@@ -11,19 +11,19 @@ from tests.unit import UnitCase
 
 class TestImportCallable(UnitCase):
     def test(self) -> None:
-        actual = typeutil.import_callable('tests.custom_classes.Class', location='')
+        actual = typeutil.import_callable('tests.custom_classes.Class', trace='')
 
         self.assertIs(Class, actual)
 
     def test__no_existing(self) -> None:
         name = 'NoExistingClass'
 
-        self.assertRaises(ObjectNotFoundError, typeutil.import_callable, name, location='')
+        self.assertRaises(ObjectNotFoundError, typeutil.import_callable, name, trace='')
 
     def test__no_callable(self) -> None:
         name = 'tests.custom_classes.CONSTANT'
 
-        self.assertRaises(ObjectNotCallableError, typeutil.import_callable, name, location='')
+        self.assertRaises(ObjectNotCallableError, typeutil.import_callable, name, trace='')
 
 
 class TestGetName(UnitCase):
@@ -72,11 +72,11 @@ class TestGetTypeHints(UnitCase):
                 self.assertEqual(expected, actual)
 
 
-class TestConvertToPrimitiveTypes(UnitCase):
+class TestConvertToPrimitives(UnitCase):
     def test(self) -> None:
         data = (True, None, {'known': 9.0, 'unknown': set()})
         expected = [True, None, {'known': 9.0, 'unknown': '???'}]
 
-        actual = typeutil.convert_to_primitive_types(data, missing_value='???')
+        actual = typeutil.convert_to_primitives(data, unknown_type='???')
 
         self.assertEqual(expected, actual)
